@@ -34,6 +34,7 @@ class module_reference:
 @dataclass
 class module_manifest:
     manifest: List[module_reference] = field(default_factory=list)
+    registries: List[str] = field(default_factory=list)
 
 
 @dataclass
@@ -106,6 +107,8 @@ class AMLModuleLoader:
         )
         self.module_cache = {}
 
+        self.registries: List[str] = []
+
         # internal manifest built from yaml config
         self.modules_manifest = {}
         self.load_config_manifest(config)
@@ -136,6 +139,9 @@ class AMLModuleLoader:
 
             self.modules_manifest[module_key] = entry
 
+        for registry in config.modules.get("registries", []):
+            self.registries.append(registry)
+
     def is_local(self, module_name):
         """Tests is module is in local list"""
         if self.use_local == "*":
@@ -242,6 +248,21 @@ class AMLModuleLoader:
         )
         loading_raised_exception = None
 
+        for registry in self.registries:
+            try:
+                log.info(f"Loading component {module_name} from registry {registry}")
+                loaded_module_class = Component.load(
+                    current_workspace(),
+                    name=module_name,
+                    version=module_version,
+                    registry=registry,
+                )
+                self.put_in_cache(module_cache_key, loaded_module_class)
+                return loaded_module_class
+
+            except BaseException as e:
+                log.warning(f"Exception: {e}")
+
         try:
             # try without namespace first
             loaded_module_class = Component.load(
